@@ -146,7 +146,7 @@ void ConfigureDialog::setSchemeList(){
 	cB_batteryScheme->clear();
 
 	for ( TQStringList::Iterator it = schemes.begin(); it != schemes.end(); ++it ) {
-		const char *_tmp = (*it).ascii();
+		const char *_tmp = (*it).utf8();
 		if(_tmp == "Performance" || _tmp == i18n("Performance")) {
 			listBox_schemes->insertItem(SmallIcon("scheme_power", TQIconSet::Automatic), i18n(_tmp));
 			cB_acScheme->insertItem(i18n(_tmp));
@@ -1271,7 +1271,7 @@ void ConfigureDialog::setInactivityBox(){
 	// actions.append("Turn Off Computer");
 	
 	for ( TQStringList::Iterator it = actions.begin(); it != actions.end(); ++it ) {
-		cB_autoInactivity->insertItem( i18n( (*it).ascii() ) );
+		cB_autoInactivity->insertItem( i18n( (*it).utf8() ) );
 	}
 
 	kdDebugFuncOut(trace);
